@@ -8,13 +8,6 @@ colMads <- function(x,method = "median", na.rm = FALSE,parallel = FALSE, cores =
 	.Call(Rfast_col_mads,x,method,na.rm,parallel,cores)
 }
 
-# #[export]
-mad2 <- function(x,method = "median",na.rm = FALSE) {
-	#.Deprecated("Rfast::Mad")
-	.Call(Rfast_mad2,x,method,na.rm)
-}
-
-
 #[export]
 Mad <- function(x,method = "median",na.rm = FALSE) {
 	.Call(Rfast_mad2,x,method,na.rm)
