@@ -1,7 +1,7 @@
 #[export]
-colrange <- function(x, cont = TRUE, parallel = FALSE){
+colrange <- function(x, cont = TRUE, parallel = FALSE,cores = 0) {
 	if(cont){
-		x <- .Call(Rfast_col_min_max,x,parallel)
+		x <- .Call(Rfast_col_min_max,x,parallel,cores)
 		return(x[2,]-x[1,])
 	}
 	.Call(Rfast_col_len_sort_un_int,x)
